#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include <SDL.h>
#include "SDL_image.h"

#ifdef _WIN32
#include <windows.h>
#endif
#ifdef WIN32
#pragma comment(lib, "SDL.lib")
#pragma comment(lib, "SDLmain.lib")
#pragma comment(lib, "SDL_image.lib")
#endif

#define LEDWIDTH 80
#define LEDHEIGHT 68

/*
 PLEASE NOTE: the program will require SDL.dll which is located in
              dev-c++'s dll directory. You have to copy it to you
			  program's home directory or the path.
 */

/* The screen surface */
SDL_Surface *screen = NULL, *bgskin=NULL;
SDL_Surface *led[2];
#define MAXFIELD 6
int field[MAXFIELD];
int range[MAXFIELD]={2,4,3,4,3,4};

/* This function draws to the screen; replace this with your own code! */
static void draw()
{
	char msg[256];
	SDL_Rect rect;
	int i,j;


	// Initialize the fields to display:
	// hour tens, hour ones, minute tens, minute ones, second tens, second ones
	time_t now=time(NULL);
	char *date=ctime(&now); // Returns "Thu Nov 24 18:22:48 1986\n\0"
	//printf(date);
	field[0]=date[11]-'0';
	field[1]=date[12]-'0';
	field[2]=date[14]-'0';
	field[3]=date[15]-'0';
	field[4]=date[17]-'0';
	field[5]=date[18]-'0';

	if(bgskin) SDL_BlitSurface(bgskin,0,screen,0);
	else SDL_FillRect(screen, NULL, SDL_MapRGB(screen->format, 0x00, 0x7f, 0x7f));


	for(i=0;i<MAXFIELD;i++) {
		for(j=0;j<range[i];j++) {
			int bit=(field[i]&(1<<j))?1:0;
			rect.x=i*LEDWIDTH;
			rect.y=272-(1+j)*LEDHEIGHT;
			rect.w=LEDWIDTH;
			rect.h=LEDHEIGHT;
			if(led[bit]) SDL_BlitSurface(led[bit],0,screen,&rect);
			else SDL_FillRect(screen, &rect, SDL_MapRGB(screen->format, bit?255:0, 0, 0));

		}
	}
	/* Make sure everything is displayed on screen */
	SDL_Flip (screen);
	/* Don't run too fast */
	SDL_Delay (17);
}


void do_cross()
{
	printf("Cross!\n");
}
void do_circle()
{
	printf("Circle!\n");
}
void do_triangle()
{
	printf("Triangle!\n");
}

extern "C" {
int main (int argc, char *argv[]);
}

int main (int argc, char *argv[])
{
    int done;
#ifdef _WIN32
	char msg[256];
#endif

    /* Initialize SDL */
    if (SDL_Init (SDL_INIT_VIDEO|SDL_INIT_JOYSTICK) < 0)
    {
#ifdef _WIN32
        sprintf (msg, "Couldn't initialize SDL: %s\n", SDL_GetError ());
        MessageBox (0, msg, "Error", MB_ICONHAND); 
        free (msg);
#endif
        exit (1);
    }
    atexit (SDL_Quit);


    /* Set 640x480 16-bits video mode */
	    screen = SDL_SetVideoMode (480, 272, 32, SDL_SWSURFACE);
	    if (screen == NULL)
	    {
	#ifdef _WIN32
		sprintf (msg, "Couldn't set 480x272x16 video mode: %s\n",
		  SDL_GetError ());
		MessageBox (0, msg, "Error", MB_ICONHAND); 
		free (msg);
	#endif
		exit (2);
	    }
	    SDL_WM_SetCaption ("Binary Clock SDL by HardHat", NULL);

	SDL_Joystick *joy=0;
	if(SDL_NumJoysticks()>0)
	   joy=SDL_JoystickOpen(0);

    
	printf("Starting.\n");
	bgskin=IMG_Load("background.png");
	printf("Loaded background.png %s\n",bgskin?"succesfully":"not!");
	led[1]=IMG_Load("ledon.png");
	printf("Loaded ledon.png %s\n",led[1]?"succesfully":"not!");
	led[0]=IMG_Load("ledoff.png");
	printf("Loaded ledoff.png %s\n",led[0]?"succesfully":"not!");


	tzset();
	done=0;

		while (!done) {
		SDL_Event event;

	        draw ();
		/* Check for events */
		if(SDL_PollEvent (&event)) {
		    /* Draw to screen */
		    switch (event.type)
		    {
		    case SDL_KEYDOWN:
			if(event.key.keysym.sym == SDLK_ESCAPE) done=1;
			if(event.key.keysym.sym == SDLK_SPACE) do_cross();
			if(event.key.keysym.sym == SDLK_LALT) do_circle();
			if(event.key.keysym.sym == SDLK_LCTRL) do_triangle();
			break;
		    case SDL_JOYBUTTONDOWN:
			if(event.jbutton.button == 11 /* START */) done=1;
			if(event.jbutton.button == 10 /* SELECT */) done=1;
			if(event.jbutton.button == 0 /* TRIANGLE */) do_triangle();
			if(event.jbutton.button == 2 /* CROSS */) do_cross();
			if(event.jbutton.button == 1 /* CIRCLE */) do_circle();
					break;
		    case SDL_QUIT:
			done = 1;
			break;
		    default:
			break;
		    }
		}

	    }

	    return 0;
}
